@@ -65,7 +65,9 @@ class MinimalConfluence:
 
     def update_page(self, page, body, parent_id=None, update_message=None):
         update_structure = {
-            "version": {"number": page.version.number + 1,},
+            "version": {
+                "number": page.version.number + 1,
+            },
             "title": page.title,
             "type": "page",
             "body": {"storage": {"value": body, "representation": "storage"}},
@@ -81,9 +83,33 @@ class MinimalConfluence:
 
         return self.api.content.put(page.id, json=update_structure)
 
-    def upload_attachment(self, page, fp):
-        return self.api.content(page.id).child.put(
+    def get_attachment(self, page, name):
+        existing_attachments = self.api.content(page.id).child.get(
             "attachment",
+            headers={"X-Atlassian-Token": "nocheck", "Accept": "application/json"},
+            params={"filename": name, "expand": "version"},
+        )
+
+        if existing_attachments.size:
+            return existing_attachments.results[0]
+
+    def update_attachment(self, page, fp, existing_attachment, message=""):
+        return (
+            self.api.content(page.id)
+            .child.attachment(existing_attachment.id)
+            .post(
+                "data",
+                data={"comment": message} if message else None,
+                format=(None, "json"),
+                headers={"X-Atlassian-Token": "nocheck"},
+                files={"file": fp},
+            )
+        )
+
+    def create_attachment(self, page, fp, message=""):
+        return self.api.content(page.id).child.post(
+            "attachment",
+            data={"comment": message} if message else None,
             format=(None, "json"),
             headers={"X-Atlassian-Token": "nocheck"},
             params={"allowDuplicated": "true"},
